@@ -562,8 +562,8 @@ def register_models(engine):
     models = (Request, Transform, Processing, Collection, Content, Health, Message)
 
     for model in models:
-        if not engine.has_table(model.__tablename__, model.metadata.schema)
-        model.metadata.create_all(engine)   # pylint: disable=maybe-no-member
+        if not engine.has_table(model.__tablename__, model.metadata.schema):
+            model.metadata.create_all(engine)   # pylint: disable=maybe-no-member
 
 
 def unregister_models(engine):
