@@ -14,9 +14,12 @@
 Test client.
 """
 
+import logging
 import string
 import random
 
+logging.basicConfig(level=logging.DEBUG)
+
 # import traceback
 
 # from rucio.client.client import Client as Rucio_Client
